package org.quartz.plugins.xmlrpc;

import org.quartz.spi.SchedulerPlugin;
import org.quartz.impl.XmlRpcScheduler;
import org.quartz.Scheduler;
import org.apache.xmlrpc.WebServer;

import java.io.IOException;

/**
 * Author: Dejan Bosanac <chubrilo@yahoo.com>
 * Date: Oct 21, 2003
 * Time: 10:08:35 PM
 *
 * Plugin that exposes scheduler API through the XML-RPC
 *
 */

public class XmlRpcPlugin implements SchedulerPlugin {

	/**
	 * XML-RPC server class
	 *  @see org.apache.xmlrpc.WebServer
	 */
    private WebServer server;

    /**
	 * Port number for server to listen
	 */
    private int port;

	/**
	 * @see org.quartz.spi.SchedulerPlugin#initialize(String, Scheduler)
	 */
    public void initialize(String name, Scheduler scheduler) {
        try {
            server = new WebServer(port);
            server.addHandler("scheduler", new XmlRpcScheduler(scheduler));
            server.start();
        } catch (IOException ioe) {
            ioe.printStackTrace();
        }

    }

	/**
	 * @see org.quartz.spi.SchedulerPlugin#shutdown()
	 */
    public void shutdown() {
        server.shutdown();
    }

	/**
	 * @return XML-RPC server port number
	 */
    public int getPort() {
        return this.port;
    }

	/**
	 * @param port XML-RPC server port number
	 */
    public void setPort(int port) {
        this.port = port;
    }

}
